@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_KOEVENTVIEWERDIALOG_H
-#define KORG_KOEVENTVIEWERDIALOG_H
+#pragma once
 
 #include "korganizerprivate_export.h"
 
@@ -49,4 +48,3 @@ private:
     QPushButton *mUser1Button = nullptr;
 };
 
-#endif
