@@ -612,7 +612,7 @@ void KODayMatrix::dropEvent(QDropEvent *e)
     if (urls.count() >= 1) {
         QUrl res = urls.at(0);
 
-        Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(Akonadi::Item::fromUrl(res));
+        auto job = new Akonadi::ItemFetchJob(Akonadi::Item::fromUrl(res));
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
         job->fetchScope().fetchFullPayload();
         Akonadi::Item::List items;
@@ -739,7 +739,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
     p.setPen(actcol);
     QPen tmppen;
 
-    const QList<QDate> workDays = KOGlobals::self()->workDays(mDays[0], mDays[NUMDAYS - 1]);
+    const QList<QDate> workDays = CalendarSupport::workDays(mDays[0], mDays[NUMDAYS - 1]);
     for (int i = 0; i < NUMDAYS; ++i) {
         row = i / 7;
         column = isRTL ? 6 - (i - row * 7) : i - row * 7;
