@@ -206,14 +206,14 @@ void ApptSummaryWidget::updateView()
     qDeleteAll(events);
 
     if (!counter) {
-        QLabel *noEvents =
+        auto noEvents =
             new QLabel(i18np("No upcoming events starting within the next day", "No upcoming events starting within the next %1 days", mDaysAhead), this);
         noEvents->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
         mLayout->addWidget(noEvents, 0, 0);
         mLabels.append(noEvents);
     }
 
-    for (QLabel *label : qAsConst(mLabels)) {
+    for (QLabel *label : std::as_const(mLabels)) {
         label->show();
     }
 }
@@ -270,8 +270,3 @@ bool ApptSummaryWidget::eventFilter(QObject *obj, QEvent *e)
 
     return KontactInterface::Summary::eventFilter(obj, e);
 }
-
-QStringList ApptSummaryWidget::configModules() const
-{
-    return QStringList() << QStringLiteral("kcmapptsummary.desktop");
-}
