@@ -204,7 +204,7 @@ void SDSummaryWidget::slotBirthdayJobFinished(KJob *job)
         const auto items = bJob->items();
         for (const Akonadi::Item &item : items) {
             if (item.hasPayload<KContacts::Addressee>()) {
-                const KContacts::Addressee addressee = item.payload<KContacts::Addressee>();
+                const auto addressee = item.payload<KContacts::Addressee>();
                 const QDate birthday = addressee.birthday().date();
                 if (birthday.isValid()) {
                     SDEntry entry;
@@ -237,7 +237,7 @@ void SDSummaryWidget::createLabels()
     // Remove all special date labels from the layout and delete them, as we
     // will re-create all labels below.
     setUpdatesEnabled(false);
-    for (QLabel *label : qAsConst(mLabels)) {
+    for (QLabel *label : std::as_const(mLabels)) {
         mLayout->removeWidget(label);
         delete (label);
         update();
@@ -625,7 +625,7 @@ void SDSummaryWidget::slotItemFetchJobDone(KJob *job)
     if (lst.isEmpty()) {
         return;
     }
-    const KContacts::Addressee contact = lst.first().payload<KContacts::Addressee>();
+    const auto contact = lst.first().payload<KContacts::Addressee>();
 
     QDesktopServices::openUrl(QUrl(contact.fullEmail()));
 }
@@ -700,9 +700,4 @@ void SDSummaryWidget::dateDiff(const QDate &date, int &days, int &years) const
     }
 }
 
-QStringList SDSummaryWidget::configModules() const
-{
-    return QStringList() << QStringLiteral("kcmsdsummary.desktop");
-}
-
 #include "sdsummarywidget.moc"
