@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_VIEWS_KOAGENDAVIEW_H
-#define KORG_VIEWS_KOAGENDAVIEW_H
+#pragma once
 
 #include "koeventview.h"
 
@@ -99,4 +98,3 @@ private:
     Private *const d;
 };
 
-#endif
