@@ -22,7 +22,7 @@
 KOTodoView::KOTodoView(bool sidebarView, QWidget *parent)
     : BaseView(parent)
 {
-    KOEventPopupMenu *eventPopup = new KOEventPopupMenu(calendar(), this);
+    auto eventPopup = new KOEventPopupMenu(calendar(), this);
     mView = new EventViews::TodoView(KOPrefs::instance()->eventViewsPreferences(), sidebarView, parent);
     auto layout = new QVBoxLayout(this);
     layout->addWidget(mView);
